{% extends "cast/cast_base.html" %}
{% load wagtailcore_tags %}

{% block body_class %}template-bloglistpage{% endblock %}

{% block content %}
<h1>{{ page.title }}</h1>
<div class="intro">{{ page.intro|richtext }}</div>

{% for post in page.get_children %}
  <h2><a href="{% pageurl post %}">{{ post.title }}</a></h2>
  <article>
    {% for block in page.body %}
      <section class="block-{{ block.block_type }}">
        {% include_block block %}
      </section>
    {% endfor %}
  </article>
{% endfor %}

{% endblock content %}
