# Generated by Django 3.1.2 on 2020-10-24 06:07

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailcore', '0052_pagelogentry'),
        ('cast', '0003_remove_post_parent_blog'),
    ]

    operations = [
        migrations.AddField(
            model_name='homepage',
            name='alias_for_page',
            field=models.ForeignKey(blank=True, default=None, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='aliases', to='wagtailcore.page'),
        ),
    ]
