# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['cast',
 'cast.api',
 'cast.management.commands',
 'cast.migrations',
 'cast.templatetags']

package_data = \
{'': ['*'],
 'cast': ['locale/de/LC_MESSAGES/*',
          'management/*',
          'static/css/*',
          'static/img/*',
          'static/img/cast/*',
          'static/js/*',
          'static/js/cast/*',
          'static/js/cast/web-player/*',
          'templates/*',
          'templates/cast/base.html',
          'templates/cast/base.html',
          'templates/cast/base.html',
          'templates/cast/base.html',
          'templates/cast/base.html',
          'templates/cast/base.html',
          'templates/cast/base.html',
          'templates/cast/base.html',
          'templates/cast/base.html',
          'templates/cast/base.html',
          'templates/cast/base.html',
          'templates/cast/base.html',
          'templates/cast/base.html',
          'templates/cast/base.html',
          'templates/cast/base.html',
          'templates/cast/base.html',
          'templates/cast/blog_detail.html',
          'templates/cast/blog_detail.html',
          'templates/cast/blog_detail.html',
          'templates/cast/blog_detail.html',
          'templates/cast/blog_detail.html',
          'templates/cast/blog_detail.html',
          'templates/cast/blog_detail.html',
          'templates/cast/blog_detail.html',
          'templates/cast/blog_detail.html',
          'templates/cast/blog_detail.html',
          'templates/cast/blog_detail.html',
          'templates/cast/blog_detail.html',
          'templates/cast/blog_detail.html',
          'templates/cast/blog_detail.html',
          'templates/cast/blog_detail.html',
          'templates/cast/blog_detail.html',
          'templates/cast/blog_index_page.html',
          'templates/cast/blog_index_page.html',
          'templates/cast/blog_index_page.html',
          'templates/cast/blog_index_page.html',
          'templates/cast/blog_index_page.html',
          'templates/cast/blog_index_page.html',
          'templates/cast/blog_index_page.html',
          'templates/cast/blog_index_page.html',
          'templates/cast/blog_index_page.html',
          'templates/cast/blog_index_page.html',
          'templates/cast/blog_index_page.html',
          'templates/cast/blog_index_page.html',
          'templates/cast/blog_index_page.html',
          'templates/cast/blog_index_page.html',
          'templates/cast/blog_index_page.html',
          'templates/cast/blog_index_page.html',
          'templates/cast/blog_list_of_posts.html',
          'templates/cast/blog_list_of_posts.html',
          'templates/cast/blog_list_of_posts.html',
          'templates/cast/blog_list_of_posts.html',
          'templates/cast/blog_list_of_posts.html',
          'templates/cast/blog_list_of_posts.html',
          'templates/cast/blog_list_of_posts.html',
          'templates/cast/blog_list_of_posts.html',
          'templates/cast/blog_list_of_posts.html',
          'templates/cast/blog_list_of_posts.html',
          'templates/cast/blog_list_of_posts.html',
          'templates/cast/blog_list_of_posts.html',
          'templates/cast/blog_list_of_posts.html',
          'templates/cast/blog_list_of_posts.html',
          'templates/cast/blog_list_of_posts.html',
          'templates/cast/blog_list_of_posts.html',
          'templates/cast/blog_page.html',
          'templates/cast/blog_page.html',
          'templates/cast/blog_page.html',
          'templates/cast/blog_page.html',
          'templates/cast/blog_page.html',
          'templates/cast/blog_page.html',
          'templates/cast/blog_page.html',
          'templates/cast/blog_page.html',
          'templates/cast/blog_page.html',
          'templates/cast/blog_page.html',
          'templates/cast/blog_page.html',
          'templates/cast/blog_page.html',
          'templates/cast/blog_page.html',
          'templates/cast/blog_page.html',
          'templates/cast/blog_page.html',
          'templates/cast/blog_page.html',
          'templates/cast/cast_base.html',
          'templates/cast/cast_base.html',
          'templates/cast/cast_base.html',
          'templates/cast/cast_base.html',
          'templates/cast/cast_base.html',
          'templates/cast/cast_base.html',
          'templates/cast/cast_base.html',
          'templates/cast/cast_base.html',
          'templates/cast/cast_base.html',
          'templates/cast/cast_base.html',
          'templates/cast/cast_base.html',
          'templates/cast/cast_base.html',
          'templates/cast/cast_base.html',
          'templates/cast/cast_base.html',
          'templates/cast/cast_base.html',
          'templates/cast/cast_base.html',
          'templates/cast/dashboard.html',
          'templates/cast/dashboard.html',
          'templates/cast/dashboard.html',
          'templates/cast/dashboard.html',
          'templates/cast/dashboard.html',
          'templates/cast/dashboard.html',
          'templates/cast/dashboard.html',
          'templates/cast/dashboard.html',
          'templates/cast/dashboard.html',
          'templates/cast/dashboard.html',
          'templates/cast/dashboard.html',
          'templates/cast/dashboard.html',
          'templates/cast/dashboard.html',
          'templates/cast/dashboard.html',
          'templates/cast/dashboard.html',
          'templates/cast/dashboard.html',
          'templates/cast/home_page.html',
          'templates/cast/home_page.html',
          'templates/cast/home_page.html',
          'templates/cast/home_page.html',
          'templates/cast/home_page.html',
          'templates/cast/home_page.html',
          'templates/cast/home_page.html',
          'templates/cast/home_page.html',
          'templates/cast/home_page.html',
          'templates/cast/home_page.html',
          'templates/cast/home_page.html',
          'templates/cast/home_page.html',
          'templates/cast/home_page.html',
          'templates/cast/home_page.html',
          'templates/cast/home_page.html',
          'templates/cast/home_page.html',
          'templates/cast/image_form.html',
          'templates/cast/image_form.html',
          'templates/cast/image_form.html',
          'templates/cast/image_form.html',
          'templates/cast/image_form.html',
          'templates/cast/image_form.html',
          'templates/cast/image_form.html',
          'templates/cast/image_form.html',
          'templates/cast/image_form.html',
          'templates/cast/image_form.html',
          'templates/cast/image_form.html',
          'templates/cast/image_form.html',
          'templates/cast/image_form.html',
          'templates/cast/image_form.html',
          'templates/cast/image_form.html',
          'templates/cast/image_form.html',
          'templates/cast/post.html',
          'templates/cast/post.html',
          'templates/cast/post.html',
          'templates/cast/post.html',
          'templates/cast/post.html',
          'templates/cast/post.html',
          'templates/cast/post.html',
          'templates/cast/post.html',
          'templates/cast/post.html',
          'templates/cast/post.html',
          'templates/cast/post.html',
          'templates/cast/post.html',
          'templates/cast/post.html',
          'templates/cast/post.html',
          'templates/cast/post.html',
          'templates/cast/post.html',
          'templates/cast/post_detail.html',
          'templates/cast/post_detail.html',
          'templates/cast/post_detail.html',
          'templates/cast/post_detail.html',
          'templates/cast/post_detail.html',
          'templates/cast/post_detail.html',
          'templates/cast/post_detail.html',
          'templates/cast/post_detail.html',
          'templates/cast/post_detail.html',
          'templates/cast/post_detail.html',
          'templates/cast/post_detail.html',
          'templates/cast/post_detail.html',
          'templates/cast/post_detail.html',
          'templates/cast/post_detail.html',
          'templates/cast/post_detail.html',
          'templates/cast/post_detail.html',
          'templates/cast/post_edit.html',
          'templates/cast/post_edit.html',
          'templates/cast/post_edit.html',
          'templates/cast/post_edit.html',
          'templates/cast/post_edit.html',
          'templates/cast/post_edit.html',
          'templates/cast/post_edit.html',
          'templates/cast/post_edit.html',
          'templates/cast/post_edit.html',
          'templates/cast/post_edit.html',
          'templates/cast/post_edit.html',
          'templates/cast/post_edit.html',
          'templates/cast/post_edit.html',
          'templates/cast/post_edit.html',
          'templates/cast/post_edit.html',
          'templates/cast/post_edit.html',
          'templates/cast/post_list.html',
          'templates/cast/post_list.html',
          'templates/cast/post_list.html',
          'templates/cast/post_list.html',
          'templates/cast/post_list.html',
          'templates/cast/post_list.html',
          'templates/cast/post_list.html',
          'templates/cast/post_list.html',
          'templates/cast/post_list.html',
          'templates/cast/post_list.html',
          'templates/cast/post_list.html',
          'templates/cast/post_list.html',
          'templates/cast/post_list.html',
          'templates/cast/post_list.html',
          'templates/cast/post_list.html',
          'templates/cast/post_list.html',
          'templates/cast/video_form.html',
          'templates/cast/video_form.html',
          'templates/cast/video_form.html',
          'templates/cast/video_form.html',
          'templates/cast/video_form.html',
          'templates/cast/video_form.html',
          'templates/cast/video_form.html',
          'templates/cast/video_form.html',
          'templates/cast/video_form.html',
          'templates/cast/video_form.html',
          'templates/cast/video_form.html',
          'templates/cast/video_form.html',
          'templates/cast/video_form.html',
          'templates/cast/video_form.html',
          'templates/cast/video_form.html',
          'templates/cast/video_form.html',
          'templates/cast/wagtail_gallery_block.html',
          'templates/cast/wagtail_gallery_block.html',
          'templates/cast/wagtail_gallery_block.html',
          'templates/cast/wagtail_gallery_block.html',
          'templates/cast/wagtail_gallery_block.html',
          'templates/cast/wagtail_gallery_block.html',
          'templates/cast/wagtail_gallery_block.html',
          'templates/cast/wagtail_gallery_block.html',
          'templates/cast/wagtail_gallery_block.html',
          'templates/cast/wagtail_gallery_block.html',
          'templates/cast/wagtail_gallery_block.html',
          'templates/cast/wagtail_gallery_block.html',
          'templates/cast/wagtail_gallery_block.html',
          'templates/cast/wagtail_gallery_block.html',
          'templates/cast/wagtail_gallery_block.html',
          'templates/cast/wagtail_gallery_block.html',
          'templates/cast/wagtail_image.html',
          'templates/cast/wagtail_image.html',
          'templates/cast/wagtail_image.html',
          'templates/cast/wagtail_image.html',
          'templates/cast/wagtail_image.html',
          'templates/cast/wagtail_image.html',
          'templates/cast/wagtail_image.html',
          'templates/cast/wagtail_image.html',
          'templates/cast/wagtail_image.html',
          'templates/cast/wagtail_image.html',
          'templates/cast/wagtail_image.html',
          'templates/cast/wagtail_image.html',
          'templates/cast/wagtail_image.html',
          'templates/cast/wagtail_image.html',
          'templates/cast/wagtail_image.html',
          'templates/cast/wagtail_image.html',
          'templates/comments/*']}

install_requires = \
['Pillow>=7,<8',
 'coreapi>=2.3.3,<3.0.0',
 'django-allauth>=0.42,<0.43',
 'django-ckeditor>=6,<7',
 'django-environ>=0.4.5,<0.5.0',
 'django-filepond>=0.1.2,<0.2.0',
 'django-filter>=2.2.0,<3.0.0',
 'django-imagekit>=4.0.2,<5.0.0',
 'django-model-utils>=4.0.0,<5.0.0',
 'django-threadedcomments>=1.2,<2.0',
 'django-watson>=1.5.4,<2.0.0',
 'django>=3.1,<4.0',
 'djangorestframework>=3.11.0,<4.0.0',
 'feedparser>=6,<7',
 'markdown>=3.2.1,<4.0.0',
 'plotly>=4.5.2,<5.0.0',
 'python-slugify>=4.0.0,<5.0.0',
 'wagtail>=2.8,<3.0',
 'wagtail_srcset>=0.1,<0.2']

entry_points = \
{'console_scripts': ['autoformat = commands:black',
                     'clean = commands:clean',
                     'clean-build = commands:clean_build',
                     'clean-pyc = commands:clean_pyc',
                     'docs = commands:docs',
                     'lint = commands:flake8',
                     'notebook = commands:notebook',
                     'show_coverage = commands:coverage',
                     'test = commands:test']}

setup_kwargs = {
    'name': 'django-cast',
    'version': '0.1.33',
    'description': 'Just another blogging / podcasting package',
    'long_description': '',
    'author': 'Jochen Wersdörfer',
    'author_email': 'jochen@wersdoerfer.de',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/ephes/django-cast',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
